==> haskell-hasql-0.19.18.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 0.19.18.1
id: hasql-0.19.18.1-CbkuCJTLEEt527slNVRvce
key: hasql-0.19.18.1-CbkuCJTLEEt527slNVRvce
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Query
    Hasql.Session
hidden-modules: Hasql.Private.Prelude Hasql.Private.PTI
                Hasql.Private.IO Hasql.Private.Query Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
abi: 17ed22ef072307f3ebf15101f95cfaff
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-0.19.18.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-0.19.18.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/hasql-0.19.18.1
hs-libraries: HShasql-0.19.18.1-CbkuCJTLEEt527slNVRvce
depends:
    attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j
    postgresql-binary-0.12.1-4dnBmFvLHOT3OJ2jT7hiKO
    postgresql-libpq-0.9.3.1-CXlU41KFsMy8E9CIoEe7GF
    bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    hashtables-1.2.1.1-5Oaw7XKpRCC6AVfg0GekD
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    profunctors-5.2.1-tcGHrJuwpB2Qib1uMFFo0
    contravariant-extras-0.3.3.1-1EzoIHtzY9A7OJ5Quev52G
    contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe
    either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 transformers-0.5.2.0
    loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM
    placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT base-4.10.0.0
abi-depends: attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=f0c2def3bf3035ee5fff7e67af1419bc
             postgresql-binary-0.12.1-4dnBmFvLHOT3OJ2jT7hiKO=0576149a3ce0789bb08f457daee41552
             postgresql-libpq-0.9.3.1-CXlU41KFsMy8E9CIoEe7GF=cd8aade0277d36035a5637b6e7273504
             bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5=d40d187de644610e0e6c5a7aac48c036
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=6edd8840a7515cd02f06202b07333d6e
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             hashtables-1.2.1.1-5Oaw7XKpRCC6AVfg0GekD=611a4fb84ed65a3586544977cdff7e6d
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=5285d4c9a9fd47aab57774d045fde1ac
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=f833729171d8aeedacf984b736ec248c
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=b4f1dc33e75c56b9a2dc645c2701b72a
             profunctors-5.2.1-tcGHrJuwpB2Qib1uMFFo0=452ba470dee5468fae2df131cd1708d4
             contravariant-extras-0.3.3.1-1EzoIHtzY9A7OJ5Quev52G=1f64fe44874d4e25d0b39f2e44ca40d3
             contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe=a01d65f47ceb3bf15b10adec053960e0
             either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj=81d1985a5d873f09e70b66c8c6890006
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM=18ff74c9d54855329085d5d1b2ddc72f
             placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK=ab5eb14aea61de13ab91be5e237b0ba7
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=b90da37ac42a33b96ab023921895831f
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-0.19.18.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 0.19.18.1
id: hasql-0.19.18.1-2BC0bq1sJuqGkkl2zBe0oa
key: hasql-0.19.18.1-2BC0bq1sJuqGkkl2zBe0oa
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Query
    Hasql.Session
hidden-modules: Hasql.Private.Prelude Hasql.Private.PTI
                Hasql.Private.IO Hasql.Private.Query Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
abi: 2e4d1b0293e628006a1710dd98f28b55
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-0.19.18.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hasql-0.19.18.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/hasql-0.19.18.1
hs-libraries: HShasql-0.19.18.1-2BC0bq1sJuqGkkl2zBe0oa
depends:
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    postgresql-binary-0.12.1-DuM7uCa68BsL5OUDy56vid
    postgresql-libpq-0.9.3.1-CXlU41KFsMy8E9CIoEe7GF
    bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    hashtables-1.2.1.1-5Oaw7XKpRCC6AVfg0GekD
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    profunctors-5.2.1-tcGHrJuwpB2Qib1uMFFo0
    contravariant-extras-0.3.3.1-1EzoIHtzY9A7OJ5Quev52G
    contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe
    either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 transformers-0.5.2.0
    loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM
    placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT base-4.10.0.0
abi-depends: attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=754c9623208b731856696d360a56d5ab
             postgresql-binary-0.12.1-DuM7uCa68BsL5OUDy56vid=71d038ea1de8611835602cf78cfa08f4
             postgresql-libpq-0.9.3.1-CXlU41KFsMy8E9CIoEe7GF=cd8aade0277d36035a5637b6e7273504
             bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5=d40d187de644610e0e6c5a7aac48c036
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=6edd8840a7515cd02f06202b07333d6e
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             hashtables-1.2.1.1-5Oaw7XKpRCC6AVfg0GekD=611a4fb84ed65a3586544977cdff7e6d
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=5285d4c9a9fd47aab57774d045fde1ac
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=f833729171d8aeedacf984b736ec248c
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=b4f1dc33e75c56b9a2dc645c2701b72a
             profunctors-5.2.1-tcGHrJuwpB2Qib1uMFFo0=452ba470dee5468fae2df131cd1708d4
             contravariant-extras-0.3.3.1-1EzoIHtzY9A7OJ5Quev52G=1f64fe44874d4e25d0b39f2e44ca40d3
             contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe=a01d65f47ceb3bf15b10adec053960e0
             either-4.4.1.1-BLyq5hWqBUdI3ApkWRKYZj=81d1985a5d873f09e70b66c8c6890006
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM=18ff74c9d54855329085d5d1b2ddc72f
             placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK=ab5eb14aea61de13ab91be5e237b0ba7
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=b90da37ac42a33b96ab023921895831f
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
